labeltools.label_tie_chains_in_expr_with_tie_chain_duration
===========================================================

.. autofunction:: abjad.tools.labeltools.label_tie_chains_in_expr_with_tie_chain_duration.label_tie_chains_in_expr_with_tie_chain_duration
   :noindex:
